#!/bin/ksh
# ----------------------------------------------------------------------------------------------------------
# This will migrate a previous embedded WAS express to the new embedded WAS express.
# 
# Pre-condition: The previous version of WAS should still be installed and the webadmin WAR file should still
#                be deployed. 
#                The new embedded WAS must already be installed.
#                The new Webadmin must already be installed.
# ----------------------------------------------------------------------------------------------------------


usage()
{
 echo "Usage:
         idswmigr.sh [-s -t -l] [-v]
      where:
     
       required fields are:
        -s is the source location for the previous version of embedded WebSphere Express (version to be migrated)
        -t is the target location where the new embedded WebSphere Express has been installed
        -l is the location for temporary files
     
       optional fields are:
        -v is the version"  
  	
   exit 0
   
} 
version()
{
  echo "IBM Tivoli Directory Server $thisRel migration for embedded WebSphere Application Server - Express"
  exit 0
}


parseParams()
{
	while [ $# -ge 1 ]; do
	case $1 in
		-s)
			APPSRV_PREV_INSTALLROOT=$2
			shift
		;;
		-t)
			APPSRV_INSTALLROOT=$2
			shift
		;;
		-l)
			LDAP_TEMP_INSTALLFILES=$2
			shift
		;;
		-v)
			version
		;;
		-Usage|-usage|-?)
			usage
		;;	
		*)
			usage
		;;
	esac
	shift;
   done

 if [ "$APPSRV_PREV_INSTALLROOT" = "" ] || [ "$APPSRV_INSTALLROOT" = "" ] || [ "$LDAP_TEMP_INSTALLFILES" = "" ]; then
    usage
 fi
}

setHome()
{
 OSname=`${UNAME}`
# echo $OSname
 if [ "$OSname" = "Linux" ]; then
  {
   IBMName="ibm"
  }
 else  {     
   IBMName="IBM"
  } 
 fi 
 
  LDAP_INSTALLHOME=/opt/$IBMName/ldap/$thisRel
# echo $LDAP_INSTALLHOME 
}



checkDirs()
{
# ----------------------------------------------------------------------------------------------------------
# Check for existence of directories 
# ----------------------------------------------------------------------------------------------------------
  
  if [ ! -d $APPSRV_PREV_INSTALLROOT ]; then
    {
	   echo "ERROR: The previous embedded WebSphere Application Server - Express directory does not exist.
	         Specify a valid directory."
	   retCode=1
     echo "returnCode " $retCode 
  	 exit $retCode  
  	}       
   fi
   
  if [ ! -f $APPSRV_PREV_INSTALLROOT/bin/wsadmin.sh ]; then
    {
	   echo "ERROR: The previous embedded WebSphere Application Server - Express directory is not valid.
	         Specify a valid directory."
	   retCode=1
     echo "returnCode " $retCode 
  	 exit $retCode  
  	}       
   fi
   
   
  if [ ! -d $APPSRV_INSTALLROOT ]; then
    {
	   echo "ERROR: The current embedded WebSphere Application Server - Express directory does not exist.
	         Specify a valid directory."
	   retCode=1
     echo "returnCode " $retCode 
  	 exit $retCode
  	}        
   fi
   
     
  if [ ! -f $APPSRV_INSTALLROOT/bin/WASPreUpgrade.sh ]; then
    {
	   echo "ERROR: The current embedded WebSphere Application Server - Express directory is not valid.
	         Specify a valid directory."
	   retCode=1
     echo "returnCode " $retCode 
  	 exit $retCode
  	}        
   fi
   
         
  if [ -d $APPSRV_INSTALLROOT/installedApps/DefaultNode/IDSWebApp.war.ear/IDSWebApp.war/WEB-INF/classes ]; then
    {
	   echo "ERROR: The current embedded WebSphere Application Server - Express directory contains a deployed IBM Tivoli Directory Server Web Administration Tool. Migration is not possible."
	   retCode=1
     echo "returnCode " $retCode 
  	 exit $retCode
  	}        
   fi
   
  if [ ! -d $LDAP_INSTALLHOME/idstools ]; then
    {
	  echo "ERROR: The current IBM Tivoli Directory Web Administration tool must be installed."
	   retCode=1
     echo "returnCode " $retCode 
  	 exit $retCode
  	}         
   fi
 
APPSRV_SAVE=appsrv

}

backupFiles()
{
echo "Backing up files"
# ----------------------------------------------------------------------------------------------------------
# Backup webadmin files from previous release 
# ----------------------------------------------------------------------------------------------------------
 PREV_APPSRV_WEBADMIN_PATH=$APPSRV_PREV_INSTALLROOT/installedApps/DefaultNode/IDSWebApp.war.ear/IDSWebApp.war/WEB-INF/classes
 if [ ! -d $LDAP_INSTALLHOME/etc ]; then
      mkdir -p $LDAP_INSTALLHOME/etc  2> /dev/null
 fi
 if [ ! -d $LDAP_INSTALLHOME/etc/$APPSRV_SAVE  ]; then
      mkdir -p $LDAP_INSTALLHOME/etc/$APPSRV_SAVE  2> /dev/null
 fi
 cp -rp "$PREV_APPSRV_WEBADMIN_PATH/security/console_passwd" "$LDAP_INSTALLHOME/etc/$APPSRV_SAVE" 2>/dev/null
        rc=$?
				if [ $rc -ne 0 ]; then
					errorCopying $rc
				fi
 cp -rp "$PREV_APPSRV_WEBADMIN_PATH/IDSConfig/IDSSessionConfig/IDSSessionMgmt.xml" "$LDAP_INSTALLHOME/etc/$APPSRV_SAVE" 2>/dev/null
        rc=$?
				if [ $rc -ne 0 ]; then
					errorCopying $rc
				fi
 cp -rp "$PREV_APPSRV_WEBADMIN_PATH/IDSConfig/IDSServersConfig/IDSServersInfo.xml" "$LDAP_INSTALLHOME/etc/$APPSRV_SAVE" 2>/dev/null
        rc=$?
				if [ $rc -ne 0 ]; then
					errorCopying $rc
				fi
 cp -rp "$PREV_APPSRV_WEBADMIN_PATH/IDSConfig/IDSAppReg/IDSAppReg.xml" "$LDAP_INSTALLHOME/etc/$APPSRV_SAVE" 2>/dev/null
        rc=$?
				if [ $rc -ne 0 ]; then
					errorCopying $rc
				fi				
}

migrate()
{
echo "Migrating"
# ----------------------------------------------------------------------------------------------------------
# uninstall war file from previous release. We need to do this since we know we do not want to use
# this old war file. We plan to use the war file from the new release. We need to do this before WASPreUpgrade
# is run, otherwise the pre-upgrade backs this up.
# -----------------------------------------------------------------------------------------------------------
echo "$APPSRV_PREV_INSTALLROOT/bin/wsadmin.sh " "-conntype NONE -c " "\$AdminApp uninstall IDSWebApp.war"
"$APPSRV_PREV_INSTALLROOT/bin/wsadmin.sh" -conntype NONE -c "\$AdminApp uninstall IDSWebApp.war"

        rc=$?
				if [ $rc -ne 0 ]; then
					wasErrUninstall $rc
				fi

# ----------------------------------------------------------------------------------------------------------
# Stop the application server - if this fails we will assume it was not started and continue with migration
# ----------------------------------------------------------------------------------------------------------
echo "$APPSRV_PREV_INSTALLROOT/bin/stopServer.sh server1"
"$APPSRV_PREV_INSTALLROOT/bin/stopServer.sh" server1

# ----------------------------------------------------------------------------------------------------------
# Migrate - preUpgrade - give temp dir followed by old install dir
# ----------------------------------------------------------------------------------------------------------
echo "$APPSRV_INSTALLROOT/bin/WASPreUpgrade.sh" $LDAP_TEMP_INSTALLFILES $APPSRV_PREV_INSTALLROOT
"$APPSRV_INSTALLROOT/bin/WASPreUpgrade.sh" $LDAP_TEMP_INSTALLFILES $APPSRV_PREV_INSTALLROOT

        rc=$?
				if [ $rc -ne 0 ]; then
					wasPreupgradeErr $rc
				fi 

# ----------------------------------------------------------------------------------------------------------
# Migrate - postUpgrade - give temp dir 
# ----------------------------------------------------------------------------------------------------------
echo "$APPSRV_INSTALLROOT/bin/WASPostUpgrade.sh $LDAP_TEMP_INSTALLFILES -replacePorts true"
"$APPSRV_INSTALLROOT/bin/WASPostUpgrade.sh" $LDAP_TEMP_INSTALLFILES -replacePorts true

        rc=$?
				if [ $rc -ne 0 ]; then
					wasPostupgradeErr $rc
				fi 

}

installWar()
{
 echo "Installing War File"
 
# ---------------------------------------------------------------------------------------------------------- 
# This copies the war file from where it was installed to the application server directory
# First, make the directory if it's not there.
# For AIX, the WAR file might be in the nossl directory, so need to check there
# ----------------------------------------------------------------------------------------------------------
test -d $APPSRV_INSTALLROOT/installableApps || mkdir "$APPSRV_INSTALLROOT/installableApps"
if [ -f "$LDAP_INSTALLHOME/idstools/IDSWebApp.war" ]; then
    cp "$LDAP_INSTALLHOME/idstools/IDSWebApp.war" "$APPSRV_INSTALLROOT/installableApps"
    rc=$?
	  if [ $rc -ne 0 ]; then
			warCopyErr $rc
		fi 
elif [ -f "$LDAP_INSTALLHOME/idstools/nossl/IDSWebApp.war" ]; then
    cp "$LDAP_INSTALLHOME/idstools/nossl/IDSWebApp.war" "$APPSRV_INSTALLROOT/installableApps"
    rc=$?
	  if [ $rc -ne 0 ]; then
			warCopyErr $rc
		fi 
else
    # No war file was found. We should exit.
    rc=99
	  if [ $rc -ne 0 ]; then
			warCopyErr $rc
		fi 
fi  
 
 
 # ----------------------------------------------------------------------------------------------------------
 # Now install the new WAR file into the new Was product
 # ----------------------------------------------------------------------------------------------------------
 "$APPSRV_INSTALLROOT/bin/wsadmin.sh" -conntype NONE -c "\$AdminApp install {$APPSRV_INSTALLROOT/installableApps/IDSWebApp.war} {-configroot \"$APPSRV_INSTALLROOT/config\" -node DefaultNode -usedefaultbindings -nodeployejb -appname IDSWebApp.war -contextroot \"IDSWebApp\"}"
        rc=$?
				if [ $rc -ne 0 ]; then
					wsadminErr $rc
				fi 
 
 
 # ----------------------------------------------------------------------------------------------------------
 # Restore the webadmin configuration files saved previously
 # ----------------------------------------------------------------------------------------------------------
 APPSRV_WEBADMIN_PATH=$APPSRV_INSTALLROOT/installedApps/DefaultNode/IDSWebApp.war.ear/IDSWebApp.war/WEB-INF/classes
 cp -rp "$LDAP_INSTALLHOME/etc/$APPSRV_SAVE/console_passwd" "$APPSRV_WEBADMIN_PATH/security/"  2>/dev/null
        rc=$?
				if [ $rc -ne 0 ]; then
					errorRestoring $rc
				fi
 cp -rp "$LDAP_INSTALLHOME/etc/$APPSRV_SAVE/IDSSessionMgmt.xml" "$APPSRV_WEBADMIN_PATH/IDSConfig/IDSSessionConfig/"  2>/dev/null
        rc=$?
				if [ $rc -ne 0 ]; then
					errorRestoring $rc
				fi
 cp -rp "$LDAP_INSTALLHOME/etc/$APPSRV_SAVE/IDSServersInfo.xml" "$APPSRV_WEBADMIN_PATH/IDSConfig/IDSServersConfig/"  2>/dev/null
        rc=$?
				if [ $rc -ne 0 ]; then
					errorRestoring $rc
				fi
 cp -rp "$LDAP_INSTALLHOME/etc/$APPSRV_SAVE/IDSAppReg.xml" "$APPSRV_WEBADMIN_PATH/IDSConfig/IDSAppReg/"  2>/dev/null
        rc=$?
				if [ $rc -ne 0 ]; then
					errorRestoring $rc
				fi				
}

errorCopying()
{
	echo "ERROR:  Cannot backup previous IDSWebApp configuration. Migration cannot continue."
	echo "returnCode " $1
	exit $1
}

wasErrUninstall()
{
	echo "ERROR:  The IDSWebApp.war uninstall failed. Migration cannot continue."
	echo "returnCode " $1
	exit $1
}


wasPreupgradeErr()
{
	echo "ERROR:  The embedded WAS PreUpgrade failed. Migration cannot continue."
	echo "returnCode " $1
	exit $1
}


wasPostupgradeErr()
{
	echo "ERROR:  The embedded WAS PostUpgrade failed. Migration cannot continue."
	echo "returnCode " $1
	exit $1
}

warCopyErr()
{
	echo "ERROR:  Error copying the IDSWebApp.war. Migration cannot continue."
	echo "returnCode " $1
	exit $1
}


wsadminErr()
{
	echo "ERROR:  Error executing wsadmin command. Migration cannot continue."
	echo "returnCode " $1
	exit $1
}

errorRestoring()
{
	echo "ERROR:  Cannot restore previous IDSWebApp configuration. Backed up files stored at: $LDAP_INSTALLHOME/etc/$APPSRV_SAVE"
	echo "returnCode " $1
	exit $1
}

#----------------------------------------------------------------------------
# Mainline
#----------------------------------------------------------------------------
#echo "enterring"
thisRel=V6.0

if [ -f /usr/bin/uname ]; then
   UNAME=/usr/bin/uname
elif [ -f /bin/uname ]; then
   UNAME=/bin/uname
else
   UNAME=uname
fi

if [ $# -eq 0 ]; then
  {
   #echo "no Parms"
	 usage
	 }
else
  {
   #echo "parms"
	 parseParams $*
	} 
fi 

setHome
checkDirs
backupFiles
migrate  
installWar
#-------------------------------------------------------------
# if we made it to here, it's a zero return code!
#-------------------------------------------------------------
echo "returnCode "0
exit 0
